@@ -67,6 +67,9 @@ sub makeLexer {
       $WHITES = $w.'gc and $self->tokenline($1 =~ tr{\n}{});';
     }
   }
+
+  my $INCREMENTAL = defined($self->{GRAMMAR}{INCREMENTAL}) ? _incrementalLexerText() : '';
+
   my %term = %{$self->{GRAMMAR}{TERM}};
   delete $term{"\c@"};
   delete $term{'error'};
@@ -118,6 +121,7 @@ EORT
   }
 
   my $frame = _lexerFrame();
+  $frame =~ s/<<INCREMENTAL>>/$INCREMENTAL/;
   $frame =~ s/<<WHITES>>/$WHITES/;
   $frame =~ s/<<TERM>>/$TERM/;
   $frame =~ s/<<DEFINEDTOKENS>>/$DEFINEDTOKENS/;
@@ -125,6 +129,18 @@ EORT
   return $frame;
 }
 
+sub _incrementalLexerText {
+
+  return << 'ENDOFINCREMENTAL';
+if ($self->YYEndOfInput) {
+          print $a if defined($a = $self->YYPrompt);
+          my $file = $self->YYInputFile;
+          $_ = <$file>;
+          return ('', undef) unless $_;
+        }
+ENDOFINCREMENTAL
+}
+
 sub _lexerFrame {
   return << 'EOLEXER';
 # Default lexical analyzer
@@ -132,6 +148,8 @@ our $LEX = sub {
     my $self = shift;
 
     for (${$self->input}) {
+      <<INCREMENTAL>>
+
       <<WHITES>>;
 
       m{<<TERM>>}gc and return ($1, $1);
@@ -228,6 +246,8 @@ MODULINO
   $states=$self->DfaTable();
   $tail= $self->Tail();
 
+  my $prompt = $self->Prompt();
+
   # In case the file ends with documentation and without a 
   # =cut
   #
@@ -302,11 +322,13 @@ use strict;
 
 push @<<$package>>::ISA, 'Parse::Eyapp::Driver';
 
+<<$prompt>>
+
 <<$driver>>
 
 <<$defaultLexer>>
 
-sub unexpendedInput { substr($_, pos $_) }
+sub unexpendedInput { defined($_) ? substr($_, (defined(pos $_) ? pos $_ : 0)) : '' }
 
 <<$head>>
 ################ @@@@@@@@@ End of User Code @@@@@@@@@ ###################
